summaryrefslogtreecommitdiff
path: root/lib/fpending.c
diff options
context:
space:
mode:
authorBruno Haible <bruno@clisp.org>2020-10-11 14:43:20 +0200
committerBruno Haible <bruno@clisp.org>2020-10-11 14:43:20 +0200
commitfd76df5d12d6710fc94a78b91cc554b64f077c70 (patch)
tree814da876988dd629aeb2d6e2c7dbac5602d00d4a /lib/fpending.c
parent739f535bf836b25bb25e0494415be81389e77566 (diff)
downloadgnulib-fd76df5d12d6710fc94a78b91cc554b64f077c70.tar.gz
stdioext: Update comments regarding Cygwin.
* lib/fpending.c: Update comments. * lib/fpurge.c: Likewise. * lib/freadable.h: Likewise. * lib/freadable.c: Likewise. * lib/freading.h: Likewise. * lib/freading.c: Likewise. * lib/fwritable.h: Likewise. * lib/fwritable.c: Likewise. * lib/fwriting.h: Likewise. * lib/fwriting.c: Likewise.
Diffstat (limited to 'lib/fpending.c')
-rw-r--r--lib/fpending.c4
1 files changed, 2 insertions, 2 deletions
diff --git a/lib/fpending.c b/lib/fpending.c
index 802ebcba65..4cc0ea747a 100644
--- a/lib/fpending.c
+++ b/lib/fpending.c
@@ -25,7 +25,7 @@
#include "stdio-impl.h"
/* This file is not used on systems that already have the __fpending function,
- namely glibc >= 2.2, Solaris >= 7, Android API >= 23. */
+ namely glibc >= 2.2, Solaris >= 7, Cygwin >= 1.7.34, Android API >= 23. */
/* Return the number of pending (aka buffered, unflushed)
bytes on the stream, FP, that is open for writing. */
@@ -39,7 +39,7 @@ __fpending (FILE *fp)
/* GNU libc, BeOS, Haiku, Linux libc5 */
return fp->_IO_write_ptr - fp->_IO_write_base;
#elif defined __sferror || defined __DragonFly__ || defined __ANDROID__
/* FreeBSD, NetBSD, OpenBSD, DragonFly, Mac OS X, Cygwin, Minix 3, Android */
return fp->_p - fp->_bf._base;
#elif defined __EMX__ /* emx+gcc */
return fp->_ptr - fp->_buffer;
@@ -39,7 +39,7 @@ __fpending (FILE *fp)
return fp->_IO_write_ptr - fp->_IO_write_base;
#elif defined __sferror || defined __DragonFly__ || defined __ANDROID__
- /* FreeBSD, NetBSD, OpenBSD, DragonFly, Mac OS X, Cygwin, Minix 3, Android */
+ /* FreeBSD, NetBSD, OpenBSD, DragonFly, Mac OS X, Cygwin < 1.7.34, Minix 3, Android */
return fp->_p - fp->_bf._base;
#elif defined __EMX__ /* emx+gcc */